@@ -1,7 +1,6 @@
-from dataclasses import dataclass
 from typing import List, Optional
 
-from dataclasses_json import DataClassJsonMixin
+from pydantic import BaseModel, Field
 
 
 class HTTPValidationError(object):
@@ -9,8 +8,7 @@ class HTTPValidationError(object):
     detail: Optional[List["ValidationError"]] = None
 
 
-@dataclass
-class PushForm(DataClassJsonMixin):
+class PushForm(BaseModel):
     # iOS 设备的 token
     # HEX 编码的 iOS 设备的token
     token: str
@@ -19,13 +17,13 @@ class PushForm(DataClassJsonMixin):
     content: str
     # 角标数量
     # 客户端显示的角标的数量
-    badge: Optional[int] = 0
+    badge: Optional[int] = Field(0)
     # 推送分类
     # 客户端推送的分类
-    category: Optional[str] = None
+    category: Optional[str] = Field(None)
     # sandbox 环境
     # 是否使用 sandbox 环境
-    sandbox: Optional[bool] = False
+    sandbox: Optional[bool] = Field(False)
 
 
 class ValidationError(object):
