@@ -37,6 +37,6 @@ class AppleSignInApi(Shared):
         ret = resp.json()
         assert isinstance(ret, dict)
         if "error" in ret:
-            return AppleSignInFailureRet.from_dict(ret)
+            return AppleSignInFailureRet(**ret)
         else:
-            return AppleSignInSuccessRet.from_dict(ret)
+            return AppleSignInSuccessRet(**ret)
